[SCM] WebKit Debian packaging branch, debian/unstable, updated. debian/1.1.15-1-40151-g37bb677

rjw rjw at 268f45cc-cd09-0410-ab3c-d52691b4dbfc
Sat Sep 26 08:22:23 UTC 2009


The following commit has been merged in the debian/unstable branch:
commit fe44f30e4e480222be0b3b444470d6de510671fc
Author: rjw <rjw at 268f45cc-cd09-0410-ab3c-d52691b4dbfc>
Date:   Thu Jan 15 23:44:57 2004 +0000

    I previously checked the fix for 3529426, but the fix was commented out.  Oops.
    
    
    git-svn-id: http://svn.webkit.org/repository/webkit/trunk@5914 268f45cc-cd09-0410-ab3c-d52691b4dbfc

diff --git a/WebCore/kwq/KWQKHTMLPart.mm b/WebCore/kwq/KWQKHTMLPart.mm
index 99bbac8..11e211d 100644
--- a/WebCore/kwq/KWQKHTMLPart.mm
+++ b/WebCore/kwq/KWQKHTMLPart.mm
@@ -1122,12 +1122,12 @@ bool KWQKHTMLPart::canCachePage()
     // 1.  We're not a frame or frameset.
     // 2.  The page has no unload handler.
     // 3.  The page has no password fields.
     // 4.  The URL for the page is https.
     if (d->m_frames.count() ||
         parentPart() ||
         m_url.protocol().startsWith("https") || 
-	(d->m_doc && (
-//	(d->m_doc && (htmlDocument().applets().length() != 0 ||
+	(d->m_doc && (htmlDocument().applets().length() != 0 ||
                       d->m_doc->hasWindowEventListener(EventImpl::UNLOAD_EVENT) ||
 		      d->m_doc->hasPasswordField()))) {
         return false;
@@ -1122,12 +1122,12 @@ bool KWQKHTMLPart::canCachePage()
     // 2.  The page has no unload handler.
     // 3.  The page has no password fields.
-    // 4.  The URL for the page is https.
+    // 4.  The URL for the page is not https.
+    // 5.  The page has no applets.
     if (d->m_frames.count() ||
         parentPart() ||

-- 
WebKit Debian packaging



More information about the Pkg-webkit-commits mailing list